/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.metaproject.impl;

import java.io.Serializable;

import edu.stanford.smi.protege.model.Instance;
import edu.stanford.smi.protege.server.metaproject.Operation;
import edu.stanford.smi.protege.server.metaproject.MetaProject.ClsEnum;
import edu.stanford.smi.protege.server.metaproject.MetaProject.SlotEnum;

public class OperationImpl extends WrappedProtegeInstanceImpl implements Operation, Serializable {
  public final static OperationImpl READ = new OperationImpl("Read");
  public final static OperationImpl WRITE = new OperationImpl("Write");
  
  //TODO: Where should we move this, especially that this might be NCI specific?
  public final static OperationImpl PROPERTY_TAB_READ = new OperationImpl("PropertyTabRead");
  public final static OperationImpl PROPERTY_TAB_WRITE = new OperationImpl("PropertyTabWrite");

  public final static OperationImpl ONTOLOGY_TAB_READ = new OperationImpl("OntologyTabRead");
  public final static OperationImpl ONTOLOGY_TAB_WRITE = new OperationImpl("OntologyTabWrite");
  
  
  private String name;
  
  protected OperationImpl(MetaProjectImpl mp, Instance op) {
    super(mp, op, ClsEnum.Operation);
    name = (String) op.getOwnSlotValue(mp.getSlot(SlotEnum.name));
  }
  
  public OperationImpl(String name) {
    this.name = name;
  }

  public String getName() {
    return name;
  }
  
  public boolean equals(Object o) {
    if (!(o instanceof Operation))  {
      return false;
    }
    Operation other = (Operation) o;
    return name.equals(other.getName());
  }
  
  public int hashCode() {
    return name.hashCode();
  }
  
  public String toString() {
    return name;
  }
}
