/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.metaproject.impl;

import java.util.HashSet;
import java.util.Set;

import edu.stanford.smi.protege.server.metaproject.GroupAndOperation;
import edu.stanford.smi.protege.server.metaproject.GroupInstance;
import edu.stanford.smi.protege.server.metaproject.MetaProjectInstance;
import edu.stanford.smi.protege.server.metaproject.Operation;
import edu.stanford.smi.protege.server.metaproject.Policy;
import edu.stanford.smi.protege.server.metaproject.UserInstance;

public class PolicyImpl implements Policy {
  MetaProjectImpl mp;
  
  public PolicyImpl(MetaProjectImpl mp) {
    this.mp = mp;
  }
  
  private UserInstance fillFields(UserInstance user) {
    for (UserInstance realUser : mp.getUserInstances()) {
      if (user.getName().equals(realUser.getName())) {
        return realUser;
      }
    }
    throw new IllegalArgumentException("Unknown user " + user);
  }
  
  private MetaProjectInstance fillFields(MetaProjectInstance project) {
    for (MetaProjectInstance realProject : mp.getProjectInstances()) {
      if (realProject.getName().equals(project.getName())) {
        return realProject;
      }
    }
    throw new IllegalArgumentException("Unknown project " + project);
  }
  

  /*
   * The project is ignored in this implementation.
   */
  public boolean isOperationAuthorized(UserInstance user, 
                                       Operation op, 
                                       MetaProjectInstance project) {
    if (!getKnownOperations().contains(op)) {
      return true;
    }
    user = fillFields(user);
    project = fillFields(project);
    Set<GroupInstance> userGroups = user.getGroups();
    for (GroupAndOperation ga : project.getAllowedGroupOperations()) {
      if (userGroups.contains(ga.allowedGroup()) && ga.allowedOperations().contains(op)) {
        return true;
      }
    }
    return false;
  }

  /*
   * The project is ignored in this implementation.
   */
  public Set<Operation> getAllowedOperations(UserInstance user, MetaProjectInstance project) {
    Set<Operation> allowed = new HashSet<Operation>();
    user = fillFields(user);
    project = fillFields(project);
    Set<GroupInstance> userGroups = user.getGroups();
    for (GroupAndOperation ga : project.getAllowedGroupOperations()) {
      if (userGroups.contains(ga.allowedGroup())) {
        allowed.addAll(ga.allowedOperations());
      }
    }
    return allowed;
  }

  public Set<Operation> getKnownOperations() {
    return mp.getOperations();
  }

}
