/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.util;

/**
 * This is a trivial support class for the Fifo queue. We are following 
 * the convention that the linked list ends in an element containing
 * null.
 * 
 * @author tredmond
 *
 * @param <X> the type of element being entered into the linked list.
 */
public class LinkedList<X> {
  private static int lastCount = 0;
  private int counter = lastCount++;
  private LinkedList<X> next;
  private X entry;
  
  public LinkedList() {
    next = null;
    entry = null;
  }
  
  public LinkedList<X> next() {
    return next;
  }
  
  public X element() {
    return entry;
  }

  protected void setNext(LinkedList<X> next) {
    this.next = next;
  }

  protected void setElement(X x) {
    entry = x;
  }
  
  public int getCounter() {
    return counter;
  }
}
