/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.util.*;

/**
 * Lazy tree node implementation if something goes wrong with the other lazy tree logic.  The common case when a call
 * to getChildCount() returns a larger number than getChildren().  This case results in a disaster for the tree where
 * nothing appears to work.  Instead we just create a node with some noticable text.  
 */

class ErrorLazyTreeNode extends LazyTreeNode {

    ErrorLazyTreeNode(LazyTreeNode parent, Object o) {
        super(parent, "INVALID -- " + o);
    }

    public LazyTreeNode createNode(Object o) {
        return null;
    }

    public int getChildObjectCount() {
        return 0;
    }

    public Collection getChildObjects() {
        return Collections.EMPTY_SET;
    }

    public Comparator getComparator() {
        return null;
    }
}
